import requests
import json
import logging

logger = logging.getLogger(__name__)

PREFIX = "RBstat?"
MEM_ALLOCATED_TARGET = "target=circle.*.memory.allocated&format=json&time=-1min"
MEM_USAGE_TARGET = "circle.*.memory.usage&format=json&time=-1min"
VMCOUNT_TARGET = "target=circle.*.vmcount&format=json&time=-1min"
CPU_PERCENT_TARGET = "target=circle.*.cpu.percent&format=json&time=-1min"

STAT_TARGETS = {
    "mem_allocated": MEM_ALLOCATED_TARGET,
    "mem_usage": MEM_USAGE_TARGET,
    "vmcount": VMCOUNT_TARGET,
    "cpu_percent": CPU_PERCENT_TARGET,
}


def get_stat_from_dc(datacenter):
    stat = {}
    for key, target in STAT_TARGETS.items():
        url: str = f"{datacenter}/{PREFIX}{target}"
        req = requests.request(
            method="GET",
            url=url,
            verify=False,
        )
        if int(req.status_code / 100) != 2:
            logger.warning(
                f"cannot retrieve the data, from dc: {datacenter}  ({req.status_code})"
            )
        else:
            data = json.loads(req.content)
            stat[key] = [i["datapoints"][0][0] for i in data]

    return stat
